ModelLibraries

Enum ModelLibraries 

pub enum ModelLibraries {
Show 42 variants AdapterTransformers, AllenNLP, Asteroid, CoreML, Diffusers, ESPnet, Fairseq, Fastai, FastText, Flair, Flax, Graphcore, Habana, Jax, Joblib, Keras, MLAgents, NeMo, OpenCLIP, OpenVINO, Onnx, PaddleNLP, PaddlePaddle, PyannoteAudio, Pythae, PyTorch, Rust, Safetensors, SampleFactory, ScikitLearn, SentenceTransformers, Spacy, SpanMarker, Speechbrain, StableBaselines3, Stanza, TensorBoard, TensorFlow, TensorFlowTTS, TFLite, Timm, Transformers,
}
Enumerate the different model libraries available on the Hugging Face Hub

Variants



AdapterTransformers

Adapter Transformers library



AllenNLP

allenNLP library



Asteroid

Asteroid library



CoreML

Core ML library



Diffusers

Diffusers library



ESPnet

ESPnet library



Fairseq

Fairseq library



Fastai

fastai library



FastText

fastText library



Flair

Flair library



Flax

Flax library



Graphcore

Graphcore library



Habana

Habana library



Jax

JAX library



Joblib

Joblib library



Keras

Keras library



MLAgents

ML-Agents library



NeMo

NeMo library



OpenCLIP

OpenCLIP library



OpenVINO

OpenVINO library



Onnx

ONNX library



PaddleNLP

PaddleNLP library



PaddlePaddle

PaddlePaddle library



PyannoteAudio

pyannote.audio library



Pythae

Pythae library



PyTorch

PyTorch library



Rust

Rust library



Safetensors

Safetensors library



SampleFactory

Sample Factory library



ScikitLearn

Scikit-learn library



SentenceTransformers

Sentence Transformers



Spacy

spaCy library



SpanMarker

SpanMarker library



Speechbrain

speechbrain library



StableBaselines3

Stable-Baselines3 library



Stanza

Stanza library



TensorBoard

TensorBoard library



TensorFlow

TensorFlow library



TensorFlowTTS

TensorFlowTTS library



TFLite

TFLite library



Timm

Timm library



Transformers

Transformers library